==> haskell-xcffib-0.6.0-74-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-xcffib.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: xcffib
version: 0.6.0
id: xcffib-0.6.0-6ljjpftl3fB5Yl1SVsxS0a
key: xcffib-0.6.0-6ljjpftl3fB5Yl1SVsxS0a
license: LicenseRef-OtherLicense
maintainer: Tycho Andersen <tycho@tycho.ws>
author: Tycho Andersen
homepage: http://github.com/tych0/xcffib
synopsis: A cffi-based python binding for X
description:
    A cffi-based python binding for X, comparable to xpyb
category: X11
abi: 845e4bad767f953518acb3b69521d398
exposed: True
exposed-modules:
    Data.XCB.Python.Parse Data.XCB.Python.PyHelpers
import-dirs: /usr/lib/ghc-8.6.3/site-local/xcffib-0.6.0
library-dirs: /usr/lib/ghc-8.6.3/site-local/xcffib-0.6.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.3/xcffib-0.6.0
hs-libraries: HSxcffib-0.6.0-6ljjpftl3fB5Yl1SVsxS0a
depends:
    attoparsec-0.13.2.2-BKfIbjnWW4NITXC0apvm49 base-4.12.0.0
    bytestring-0.10.8.2 containers-0.6.0.1
    either-5.0.1-3eiDvThBVwwBx62eCBOSQW
    filemanip-0.3.6.3-4gIDkmoap4z2kDIgJy5hH filepath-1.4.2.1
    language-python-0.5.4-8lNcvpYAcXH7aPq0bQFhSG mtl-2.2.2
    split-0.2.3.3-9O3ah5XNSacJuZjDAE6BjK
    xcb-types-0.9.0-CyYzUqjRd3RBheFgqQW3b
haddock-interfaces: /usr/share/doc/haskell-xcffib/html/xcffib.haddock
haddock-html: /usr/share/doc/haskell-xcffib/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-xcffib-0.6.0-76-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-xcffib.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: xcffib
version: 0.6.0
id: xcffib-0.6.0-9SMBhFoMGufKEVR8rPYZcX
key: xcffib-0.6.0-9SMBhFoMGufKEVR8rPYZcX
license: LicenseRef-OtherLicense
maintainer: Tycho Andersen <tycho@tycho.ws>
author: Tycho Andersen
homepage: http://github.com/tych0/xcffib
synopsis: A cffi-based python binding for X
description:
    A cffi-based python binding for X, comparable to xpyb
category: X11
abi: 1ea37f1fa580c5cbe582487ae87bde6a
exposed: True
exposed-modules:
    Data.XCB.Python.Parse Data.XCB.Python.PyHelpers
import-dirs: /usr/lib/ghc-8.6.3/site-local/xcffib-0.6.0
library-dirs: /usr/lib/ghc-8.6.3/site-local/xcffib-0.6.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.3/xcffib-0.6.0
hs-libraries: HSxcffib-0.6.0-9SMBhFoMGufKEVR8rPYZcX
depends:
    attoparsec-0.13.2.2-BKfIbjnWW4NITXC0apvm49 base-4.12.0.0
    bytestring-0.10.8.2 containers-0.6.0.1
    either-5.0.1-JaEeaq4rSOd91bg2arGZwA
    filemanip-0.3.6.3-4gIDkmoap4z2kDIgJy5hH filepath-1.4.2.1
    language-python-0.5.4-8lNcvpYAcXH7aPq0bQFhSG mtl-2.2.2
    split-0.2.3.3-9O3ah5XNSacJuZjDAE6BjK
    xcb-types-0.9.0-CyYzUqjRd3RBheFgqQW3b
haddock-interfaces: /usr/share/doc/haskell-xcffib/html/xcffib.haddock
haddock-html: /usr/share/doc/haskell-xcffib/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
